# 📈 aql-monitoring

Monitor and manage the crawling of the [Archive Query Log](https://github.com/webis-de/archive-query-log).

## Installation

```shell
npm install
```

TODO: Add better instructions.

## Usage

For starting the website, navigate to the repo and do
```npm run dev-vite```
in your terminal
